@@ -43,3 +43,10 @@ def shorten_url(url: str) -> str:
         return str(s.tinyurl.short(url))
     except Exception:
         raise SimeLibraryError("Error occurred during shortening URL")
+def generatePass(length: int) -> int:
+    krack = [x for x in range(33, 127)]
+    word = ""
+    for x in range(length):
+        charter = random.choice(krack)
+        word += charter
+    return word
\ No newline at end of file
